@@ -30,22 +30,22 @@ int parse_cmdline (int argc, char **argv, int *xwindow, char *run_fname,
 					/* Interpret command line flags */
     *xwindow = *filelist = FALSE;
     run_fname[0] = batch_string[0] = '\0';
-    while((c=getopt(argc,argv,"b:r:xfm:")) != -1) 
+    while((c=getopt(argc,argv,"b:r:xfm:")) != -1)
 	{
 	if (*filelist)
 	    {
 	    msg ("Error. -f option must be the LAST option", 3);
-	    syntax();
+	    syntax("$HeadURL$");
 	    return (1);
 	    }
 	if (strlen (batch_string) > 0)
 	    {
 	    msg ("Error. -b option must be the ONLY option if given", 3);
-	    syntax();
+	    syntax("$HeadURL$");
 	    return (1);
 	    }
 
-	switch(c) 
+	switch(c)
 	    {
 	    case 'b':
 		strcpy (batch_string, optarg);
@@ -76,7 +76,7 @@ int parse_cmdline (int argc, char **argv, int *xwindow, char *run_fname,
 
 	    case '?':
 		msg ("Unrecognized command-line flag '-%c'", 2, c);
-		syntax();
+		syntax("$HeadURL$");
 		return (1);
 		break;
 	    }
