@@ -203,8 +203,10 @@ calc_rms (struct type_pass *pass)
                 {
                 plot.mean_ap[fr][seg] = mean_ap / wtf;
                 plot.seg_amp[fr][seg] = cabs (vsumf) / wtf_dsb;
-                plot.seg_frac_usb[fr][seg] = usbfrac / (double)apseg;
-                plot.seg_frac_lsb[fr][seg] = lsbfrac / (double)apseg;
+                plot.seg_frac_usb[fr][seg] =
+                    (usbfrac >= 0.0) ? usbfrac / (double)apseg : 0.0;
+                plot.seg_frac_lsb[fr][seg] =
+                    (lsbfrac >= 0.0) ? lsbfrac / (double)apseg : 0.0;
                 if (ref_scount_usb == 0.0) ref_scount_usb = -1.0; /* No data, no plot */
                 if (ref_scount_lsb == 0.0) ref_scount_lsb = -1.0;
                 if (rem_scount_usb == 0.0) rem_scount_usb = -1.0;
@@ -226,13 +228,18 @@ calc_rms (struct type_pass *pass)
                 }
             plot.seg_phs[fr][seg] = carg (vsumf);
                                         /* Pcals */
-            if (refpcwt == 0.0)
-                plot.seg_refpcal[fr][seg] = 1000.0;
+            if (param.pc_mode[0] == MANUAL)
+                plot.seg_refpcal[fr][seg] = status.pc_offset[fr][0][stnpol[0][pass->pol]];
+            else if (refpcwt == 0.0)
+                plot.seg_refpcal[fr][seg] = 0.0;
             else 
                 plot.seg_refpcal[fr][seg] = carg (refpc) * 180.0 / M_PI;
-            if (rempcwt == 0.0) 
-                plot.seg_rempcal[fr][seg] = 1000.0;
-            else
+
+            if (param.pc_mode[1] == MANUAL)
+                plot.seg_rempcal[fr][seg] = status.pc_offset[fr][1][stnpol[1][pass->pol]];
+            else if (rempcwt == 0.0)
+                plot.seg_rempcal[fr][seg] = 0.0;
+            else 
                 plot.seg_rempcal[fr][seg] = carg (rempc) * 180.0 / M_PI;
             }
                                         /* Record amp/phase for all freqs */
