@@ -8,6 +8,7 @@
 
 #include "control.h"
 #include "mk4_sizes.h"
+#include <string.h>
 
 #define FALSE 0
 #define TRUE 1
@@ -79,6 +80,8 @@ default_cblock (struct c_block *cb_ptr)
     cb_ptr -> mbd_anchor    = MODEL;
     cb_ptr -> ion_smooth    = FALSE;
     cb_ptr -> est_pc_manual = FALSE;
+    cb_ptr -> vbp_correct   = FALSE;
+    cb_ptr -> vbp_fit       = FALSE;
 
     for (i=0; i<2; i++)                              // clear ref and rem values
         {
@@ -88,6 +91,13 @@ default_cblock (struct c_block *cb_ptr)
         cb_ptr -> plot_data_dir[i][0] = 0;
         cb_ptr -> pc_phase_offset[i].ref = 0;
         cb_ptr -> pc_phase_offset[i].rem = 0;
+        cb_ptr -> vbp_file[i][0] = 0;
+        }
+                      
+    for (i=0; i<5; i++)
+        {                                    // clear video bandpass model coefficients
+        cb_ptr -> vbp_coeffs[i].ref = 0.0;
+        cb_ptr -> vbp_coeffs[i].rem = 0.0;
         }
                       
     for (i=0; i<6; i++)
@@ -104,7 +114,7 @@ default_cblock (struct c_block *cb_ptr)
          
     for (i=0; i<MAXFREQ; i++)
         {
-        cb_ptr -> frequency[i] = DSB;        /* accept all frequency channels */
+        cb_ptr -> accept_sbs[i] = DSB;       /* accept all frequency channels */
         cb_ptr -> pc_phase[i][0].ref = 0.0;
         cb_ptr -> pc_phase[i][1].ref = 0.0;
         cb_ptr -> pc_phase[i][0].rem = 0.0;
@@ -121,7 +131,10 @@ default_cblock (struct c_block *cb_ptr)
         cb_ptr -> delay_offs_pol[i][1].ref = 0.0;
         cb_ptr -> delay_offs_pol[i][0].rem = 0.0;
         cb_ptr -> delay_offs_pol[i][1].rem = 0.0;
+        cb_ptr -> chid_rf[i] = 0.0;
         }
 
+    strncpy (cb_ptr->chid, FCHARS, MAXFREQ); // default single letter freq codes abc...
+
     return(0);
     }
