@@ -89,8 +89,9 @@ struct type_param
 #define INTP_ERR_MBD   0x10
 #define INTP_ERR_RATE  0x20
 
-#define MK4HDW 0x01                     // values for corr_type
-#define DIFX   0x02
+#define MK4HDW 0x01                     // values for corr_type, for Alan W
+#define DIFX   0x02                     // For Adam D
+#define SFXC   0x03                     // For Mark K
 
 struct type_status 
     {
