@@ -8,13 +8,18 @@
 /************************************************************************/
 #include <stdio.h>
 #include "control.h"
-
+#include "param_struct.h"
 
 int
 set_defaults()
     {
     char *default_cfile, *getenv();
     extern struct c_block *cb_head;
+    extern struct type_param param;
+
+    //for lack of a better place to initialize this, we set these to NULL here
+    param.control_file_buff = NULL;
+    param.set_string_buff = NULL;
 
     cb_head = NULL;                     /* signifies no c_blocks yet */
 
@@ -28,7 +33,7 @@ set_defaults()
         msg ("Default control file DEF_CONTROL environment variable undefined!", 3);
         return (1);
         }
-    if (parse_control_file(default_cfile) != 0)
+    if (parse_control_file(default_cfile, &(param.control_file_buff), &(param.set_string_buff)) != 0)
         {
         msg ("Fatal error parsing default control file '%s'", 3, default_cfile);
 	msg ("You must point $DEF_CONTROL to a valid fourfit", 3);
